Learn R Programming

teal.widgets (version 0.5.1)

extract_raw_choices: Extract raw values from choices

Description

Extract raw values from choices

Usage

extract_raw_choices(choices, sep)

Value

choices simplified

Arguments

choices

(choices_labeled, list or character)
object containing choices

sep

(character(1))
A separator string to split the choices or selected inputs into the values of the different columns.