View source: R/optionalInput.R
| optionalSliderInput | R Documentation |
Hidden input widgets are useful to have the input[[inputId]] variable
on available in the server function but no corresponding visual clutter from
input widgets that provide only a single choice.
optionalSliderInput(inputId, label, min, max, value, label_help = NULL, ...)
inputId |
The |
label |
Display label for the control, or |
min, max |
The minimum and maximum values (inclusive) that can be selected. |
value |
The initial value of the slider, either a number, a date
(class Date), or a date-time (class POSIXt). A length one vector will
create a regular slider; a length two vector will create a double-ended
range slider. Must lie between |
label_help |
( |
... |
optional arguments to |
if min or max are NA then the slider widget will be hidden
(shiny.tag) HTML tag with sliderInput widget.
ui <- bslib::page_fluid(
shinyjs::useShinyjs(),
optionalSliderInput("s", "shown", 0, 1, 0.2),
optionalSliderInput("h", "hidden", 0, NA, 1),
)
if (interactive()) {
shiny::shinyApp(ui, function(input, output) {})
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.