Learn R Programming

teal.widgets (version 0.5.1)

panel_item: Panel item widget

Description

[Deprecated]
Designed to be grouped using panel_group element. Used to handle shiny inputs in the encoding panel.

Usage

panel_item(title, ..., collapsed = TRUE, input_id = NULL)

Value

(shiny.tag)

Arguments

title

(character)
title of panel

...

content of panel

collapsed

(logical) optional,
whether to initially collapse panel

input_id

(character) optional
name of the panel item element. If supplied, this will register a shiny input variable that indicates whether the panel item is open or collapsed and is accessed with input$input_id.

Examples

Run this code

library(shiny)
panel_item(
  title = "Display",
  collapsed = FALSE,
  checkboxGroupInput(
    "check",
    "Tables display",
    choices = LETTERS[1:3],
    selected = LETTERS[1]
  ),
  radioButtons(
    "radio",
    label = "Plot type",
    choices = letters[1:2],
    selected = letters[1]
  )
)

Run the code above in your browser using DataLab