Adds Small Well class and overflow-x property to HTML output element.
Usage
white_small_well(...)
Value
An HTML output element with class Small Well and overflow-x property
Arguments
...
other arguments to pass to tag object's div attributes.
Details
white_small_well is intended to be used with shiny::uiOutput().
The overflow-x property is set to auto so that a scroll bar is added
when the content overflows at the left and right edges of the output window.
For example, this is useful for displaying wide tables.